@@ -41,6 +41,8 @@ def main():
     parser.add_argument('--location', help='location of the Python modules and scripts')
     parser.add_argument('--cmd-log', help='location of the command log files')
     parser.add_argument('--module-path', help='module path of the Python modules and scripts')
+    parser.add_argument('--kernel-name',
+                        help="the kernel that will be started by default, python3 if not given")
     parser.add_argument('--config', help='a YAML file that configures the executor')
     parser.add_argument('--logo', help='path to logo PNG or SVG file')
     parser.add_argument('--app-name', help='the name of the GUI app, will go in the window title')
@@ -49,6 +51,7 @@ def main():
     args = parser.parse_args()
 
     verbosity = 0 if args.verbose is None else args.verbose
+    kernel_name = args.kernel_name or "python3"
 
     if args.version:
         from .__version__ import __version__ as version
@@ -73,7 +76,7 @@ def main():
     app = QApplication([])
     app.setWindowIcon(QIcon(args.logo or str(HERE / "icons/tasks.svg")))
 
-    view = View(args.app_name or "GUI Executor", cmd_log=args.cmd_log, verbosity=verbosity)
+    view = View(args.app_name or "GUI Executor", cmd_log=args.cmd_log, verbosity=verbosity, kernel_name=kernel_name)
     model = Model(args.module_path)
     Control(view, model)
 
