@@ -188,7 +188,8 @@ def custom_repr(arg: Any):
     if not isinstance(arg, Enum):
         return repr(arg)
 
-    m = re.fullmatch(r"<([\w.]+): (\d+)>", repr(arg))
+    m = re.fullmatch(r"<([\w.]+): (.*)>", repr(arg))
+
     return m[1]
 
 
@@ -213,6 +214,9 @@ def create_code_snippet(func: Callable, args: List, kwargs: Dict, call_func: boo
     # Check if one of the args/kwargs is an Enum
     #   * import the proper Enum class
     #   *
+
+    # [3405691582] magic number is defined in gui_executor.transforms
+
     return textwrap.dedent(
         f"""\
             # [3405691582]
